const std = @import("std");
const MicroZig = @import("microzig-build");

pub fn build(b: *std.Build) void {
    const microzig = MicroZig.createBuildEnvironment(b, .{});
    const optimize = b.standardOptimizeOption(.{});

    // `addFirmware` basically works like addExecutable, but takes a
    // `microzig.Target` for target instead of a `std.zig.CrossTarget`.
    //
    // The target will convey all necessary information on the chip,
    // cpu and potentially the board as well.
    const firmware = microzig.addFirmware(b, .{
        .name = "oled",
        .target = microzig.findTarget("board:raspberry_pi/pico").?,
        .optimize = optimize,
        .source_file = .{ .path = "oled.zig" },
    });

    // `installFirmware()` is the MicroZig pendant to `Build.installArtifact()`
    // and allows installing the firmware as a typical firmware file.
    //
    // This will also install into `$prefix/firmware` instead of `$prefix/bin`.
    microzig.installFirmware(b, firmware, .{});

    // For debugging, we also always install the firmware as an ELF file
    microzig.installFirmware(b, firmware, .{ .format = .elf });
}
